Documentation
¶
Index ¶
Constants ¶
const (
// GamePath is the path that is added to a steam path or library
GamePath = "steamapps/common/team fortress 2/tf/"
)
Variables ¶
var ( // SteamConfigLibraryExp gets library's path inside steam's config SteamConfigLibraryExp = regexp.MustCompile(`"BaseInstallFolder_[\d+]"[\s]+"(.*)"`) // GameValidFiles is a list of things that every tf2 installation must have GameValidFiles = []string{ "steamapps/common/team fortress 2/hl2.exe", "steamapps/common/team fortress 2/tf/", "steamapps/common/team fortress 2/tf/cfg/", } )
Functions ¶
func ContainsInvalidGamePath ¶
func FindGame ¶
FindGame loops through steam libraries to check if the game is inside one of them, then it returns the valid one
func FindSteamLibrary ¶
FindSteamLibrary reads steam's config file from the path found at window's registry to get all steam libraries path
func FindSteamPath ¶
func GetModuleFileName ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.